@@ -1,4 +1,4 @@
-from FreeTAKServer.controllers.DatabaseControllers.table_controllers import TableController
+from FreeTAKServer.controllers.DatabaseControllers.TableController import TableController
 from FreeTAKServer.model.SQLAlchemy.APIUsers import APIUsers
 
 class APIUsersController(TableController):
