@@ -1,12 +1,11 @@
-from FreeTAKServer.model.FTSModel.fts_protocol_object import FTSProtocolObject
 from FreeTAKServer.model.FTSModelVariables.HashVariables import HashVariables as vars
 
-class Hash(FTSProtocolObject):
+class Hash:
     def __init__(self):
         self.INTAG = None
 
     @staticmethod
-    def ExcheckUpdate(INTAG=vars.ExcheckUpdate().INTAG, ):
+    def CreateExCheckTemplate(INTAG=vars.CreateExCheckTemplate().INTAG, ):
         hash = Hash()
 
         hash.setINTAG(INTAG)
